<?php

/**
 * @file
 */

/**
 *
 */
function section_section_view_page_manager_tasks() {
  return array(
    'task type' => 'page',
    'title' => t('Section template'),
    'admin title' => t('Section template'),
    'admin description' => t('When enabled, this overrides the default behavior for displaying sections at <em>section/%section</em>.'),
    'admin path' => 'section/%section',
    'hook menu' => 'section_section_view_menu',
    'hook menu alter' => 'section_section_view_menu_alter',
    'handler type' => 'context',
    'get arguments' => 'section_section_view_get_arguments',
    'get context placeholders' => 'section_section_view_get_contexts',
    'disabled' => variable_get('section_section_view_disabled', TRUE),
    'enable callback' => 'section_section_view_enable',
  );
}

/**
 *
 */
function section_section_view_menu_alter(&$items, $task) {
  if (variable_get('section_section_view_disabled', TRUE)) {
    return;
  }

  $callback = $items['section/%section']['page callback'];
  if ($callback === 'section_page_view' || variable_get('page_manager_override_anyway', FALSE)) {
    $items['section/%section']['page callback'] = 'section_section_view_page';
    $items['section/%section']['file path'] = $task['path'];
    $items['section/%section']['file'] = $task['file'];
  }
  else {
    variable_set('section_section_view_disabled', TRUE);
    if (!empty($GLOBALS['section_enabling_section_view'])) {
      drupal_set_message(t('Page manager module is unable to enable section/%section because some other module already has overridden with %callback.', array('%callback' => $callback)), 'error');
    }
  }
}

/**
 *
 */
function section_section_view_page($section) {
  $task = page_manager_get_task('section_view');

  ctools_include('context');
  ctools_include('context-task-handler');
  $contexts = ctools_context_handler_get_task_contexts($task, '', array($section));

  $output = ctools_context_handler_render($task, '', $contexts, array($section->sid));
  if ($output != FALSE) {
    return $output;
  }

  $function = 'section_page_view';
  foreach (module_implements('page_manager_override') as $module) {
    $call = $module . '_page_manager_override';
    if (($rc = $call('section_view')) && function_exists($rc)) {
      $function = $rc;
      break;
    }
  }

  return $function($section);
}

/**
 *
 */
function section_section_view_get_arguments($task, $subtask_id) {
  return array(
    array(
      'keyword' => 'section',
      'identifier' => t('Section being viewed'),
      'id' => 1,
      'name' => 'entity_id:section',
      'settings' => array(),
    ),
  );
}

/**
 *
 */
function section_section_view_get_contexts($task, $subtask_id) {
  return ctools_context_get_placeholders_from_argument(section_section_view_get_arguments($task, $subtask_id));
}

/**
 *
 */
function section_section_view_enable($cache, $status) {
  variable_set('section_section_view_disabled', $status);

  if (!$status) {
    $GLOBALS['section_enabling_section_view'] = TRUE;
  }
}
