<?php

/**
 * @file
 */

class SectionUIController extends EntityDefaultUIController {

  /**
   * Overrides parent::hook_menu().
   */
  public function hook_menu() {
    $module_path = drupal_get_path('module', 'section');

    $items = parent::hook_menu();

    $items[$this->path . '/add'] = array(
      'title' => 'Add section',
      'description' => 'Add a new section',
      'page callback'  => 'section_add_page',
      'access callback'  => 'section_access',
      'access arguments' => array('edit'),
      'file' => 'section.admin.inc',
      'file path' => $module_path,
    );

    foreach (section_get_types() as $type) {
      $items[$this->path . '/add/' . $type->name] = array(
        'title' => $type->label,
        'description' => $type->description,
        'page callback' => 'section_add',
        'page arguments' => array($type->name),
        'access callback' => 'section_access',
        'access arguments' => array('edit', 'edit ' . $type->name),
        'file' => 'section.admin.inc',
        'file path' => $module_path,
      );
    }

    return $items;
  }

}

/**
 *
 */
function section_add_page() {
  $item = menu_get_item();
  $types = system_admin_menu_block($item);

  // Bypass the section/add listing if only one section type is available.
  if (count($types) == 1) {
    $item = array_shift($types);
    drupal_goto($item['href']);
  }

  return theme('section_add_list', array('types' => $types));
}

/**
 *
 */
function section_add($type) {
  $section = section_create(array('type' => $type));

  return drupal_get_form('section_form', $section);
}

/**
 *
 */
function section_form($form, &$form_state, $section) {
  $form_state['section'] = $section;

  $form['identifier'] = array(
    '#type' => 'container',
    '#weight' => -100
  );

  $form['identifier']['label'] = array(
    '#type' => 'textfield',
    '#title' => t('Label'),
    '#default_value' => $section->label,
    '#maxlength' => 128,
    '#required' => TRUE,
    '#description' => t('This label is just for the readable machine name.'),
  );

  $form['identifier']['name'] = array(
    '#type' => 'machine_name',
    '#default_value' => $section->name,
    '#maxlength' => 128,
    '#machine_name' => array(
      'exists' => 'section_name_exists',
      'source' => array('identifier', 'label'),
    ),
  );

  field_attach_form('section', $section, $form, $form_state);

  $form['actions'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('form-actions')),
    '#weight' => 400,
  );

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  if (!empty($section->name)) {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#submit' => array('section_form_delete'),
    );
  }

  return $form;
}

/**
 *
 */
function section_form_validate(&$form, &$form_state) {
  $section = $form_state['section'];

  field_attach_form_validate('section', $section, $form, $form_state);
}

/**
 *
 */
function section_form_submit(&$form, &$form_state) {
  $section = entity_ui_controller('section')->entityFormSubmitBuildEntity($form, $form_state);

  $section->save();

  $form_state['redirect'] = 'admin/structure/section';
}

/**
 *
 */
function section_form_delete(&$form, &$form_state) {
  $form_state['redirect'] = 'admin/structure/section/manage/' . $form_state['section']->name . '/delete';
}
